# Smol-SAE

![Github Actions](https://github.com/dtch1997/smol-sae/actions/workflows/build_and_release.yaml/badge.svg)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://pdm-project.org)

A very small, didactic SAE training library.

# Quickstart
## Installation
```
git clone https://github.com/dtch1997/smol-sae
pip install -e .
```

## Usage
Refer to `examples` for how to use an SAE. 
